@@ -3,9 +3,9 @@
  * @author Stephen Gilbert @date 2002-12-11
  */
 
+#include "grib2_int.h"
 #include <stdio.h>
 #include <stdlib.h>
-#include "grib2_int.h"
 
 /**
  * Return the dimensions and scanning mode of a grid definition.
@@ -30,75 +30,72 @@ getdim(unsigned char *csec3, g2int *width, g2int *height, g2int *iscan)
     g2int *igds = NULL;
     g2int iofst, igdtlen, num_opt, jerr;
 
-    iofst = 0;       /* set offset to beginning of section */
+    iofst = 0; /* set offset to beginning of section */
     if (!(jerr = g2_unpack3(csec3, &iofst, &igds, &igdstmpl, &igdtlen,
                             &list_opt, &num_opt)))
     {
-        switch (igds[4])     /*  Template number */
+        switch (igds[4]) /*  Template number */
         {
-        case 0:    /* Lat/Lon */
+        case 0: /* Lat/Lon */
         case 1:
         case 2:
-        case 3:
-        {
+        case 3: {
             *width = igdstmpl[7];
             *height = igdstmpl[8];
             *iscan = igdstmpl[18];
             break;
         }
-        case 10:   /* Mercator */
+        case 10: /* Mercator */
         {
             *width = igdstmpl[7];
             *height = igdstmpl[8];
             *iscan = igdstmpl[15];
             break;
         }
-        case 20:   /* Polar Stereographic */
+        case 20: /* Polar Stereographic */
         {
             *width = igdstmpl[7];
             *height = igdstmpl[8];
             *iscan = igdstmpl[17];
             break;
         }
-        case 30:   /* Lambert Conformal */
+        case 30: /* Lambert Conformal */
         {
             *width = igdstmpl[7];
             *height = igdstmpl[8];
             *iscan = igdstmpl[17];
             break;
         }
-        case 40:   /* Gaussian */
+        case 40: /* Gaussian */
         case 41:
         case 42:
-        case 43:
-        {
+        case 43: {
             *width = igdstmpl[7];
             *height = igdstmpl[8];
             *iscan = igdstmpl[18];
             break;
         }
-        case 90:   /* Space View/Orthographic */
+        case 90: /* Space View/Orthographic */
         {
             *width = igdstmpl[7];
             *height = igdstmpl[8];
             *iscan = igdstmpl[16];
             break;
         }
-        case 110:   /* Equatorial Azimuthal */
+        case 110: /* Equatorial Azimuthal */
         {
             *width = igdstmpl[7];
             *height = igdstmpl[8];
             *iscan = igdstmpl[15];
             break;
         }
-        default:
-        {
+        default: {
             *width = 0;
             *height = 0;
             *iscan = 0;
             break;
         }
-        }  /* end switch */
+        } /* end switch */
     }
     else
     {
